==> jsm-base-7.0.5-42116a.zip: src/config/jsm_datafilter.php <==
<?php

return [

	/*
    |--------------------------------------------------------------------------
    | Enable filters_in_session
    |--------------------------------------------------------------------------
    |
    | Se impostato a TRUE, la classe jsmDataFilter salverà e leggerà dalla sessione i valori dei filtri in automatico
    |
    */

	"filters_in_session" => true,
    "session_key" => "filtri_sessione",


    /*
    |--------------------------------------------------------------------------
    | max_filters_len
    |--------------------------------------------------------------------------
    |
    | Permette di specificare il numero di caratteri superato il quale verranno
    | autmaticamente cancellati tutti i filtri in sessione per evitare di andare in loop
    | aumentando a dismisura la dimensione della sessione
    |
    | il numero dei caratteri dei filtri viene conteggiato contando il risultato del serialize() dei filtri in sessione
    |
    */
    "max_filters_len" => 1000000,


    /*
    |--------------------------------------------------------------------------
    | Gestione delle classi per la revisione grafica dei form / filtri
    |--------------------------------------------------------------------------
    |
    */

    "form_class" => "form-wrapper", //classe base che viene passata ai form costruiti in automatico -- con la nuova grafica usare: "form-wrapper", legacy: "form-inline"
    "custom_view" => "layouts.txdFilter", //view di base per costruire i form -- con la nuova grafica usare: "layouts.txdFilter", legacy: "layouts.jsmDataform_inline"


    /*
    |--------------------------------------------------------------------------
    | URL in HTTPS sulla base di APP_URL
    | se impostato a TRUE, i vari url dei form e paginazione vengono impostati
    | in HTTPS o meno a seconda che nel parametro APP_URL del file .env l'url sia in https o meno
    |--------------------------------------------------------------------------
    |
    */
    "use_env_for_https" => false,

];

==> jsm-base-7.1.8-b25a64.zip: src/config/jsm_datafilter.php <==
<?php

return [

	/*
    |--------------------------------------------------------------------------
    | Enable filters_in_session
    |--------------------------------------------------------------------------
    |
    | Se impostato a TRUE, la classe jsmDataFilter salverà e leggerà dalla sessione i valori dei filtri in automatico
    |
    */

	"filters_in_session" => true,
    "session_key" => "filtri_sessione",


    /*
    |--------------------------------------------------------------------------
    | max_filters_len
    |--------------------------------------------------------------------------
    |
    | Permette di specificare il numero di caratteri superato il quale verranno
    | autmaticamente cancellati tutti i filtri in sessione per evitare di andare in loop
    | aumentando a dismisura la dimensione della sessione
    |
    | il numero dei caratteri dei filtri viene conteggiato contando il risultato del serialize() dei filtri in sessione
    |
    */
    "max_filters_len" => 1000000,


    /*
    |--------------------------------------------------------------------------
    | Gestione delle classi per la revisione grafica dei form / filtri
    |--------------------------------------------------------------------------
    |
    */

    "form_class" => "form-wrapper", //classe base che viene passata ai form costruiti in automatico -- con la nuova grafica usare: "form-wrapper", legacy: "form-inline"
    "custom_view" => "layouts.txdFilter", //view di base per costruire i form -- con la nuova grafica usare: "layouts.txdFilter", legacy: "layouts.jsmDataform_inline"


    /*
    |--------------------------------------------------------------------------
    | URL base sostituito con quello impostato in APP_URL
    | se impostato a TRUE, i vari url dei form e paginazione vengono generati
    | con la base a partire da APP_URL
    |--------------------------------------------------------------------------
    |
    */
    "root_url_from_env" => env("ROOT_URL_FROM_ENV", false),

    /*
    |--------------------------------------------------------------------------
    | URL in HTTPS sulla base di APP_URL
    | se impostato a TRUE, i vari url dei form e paginazione vengono impostati
    | in HTTPS o meno a seconda che nel parametro APP_URL del file .env l'url sia in https o meno
    | se il parametro "root_url_from_env" e' impostato a TRUE, la modifica a questo campo non ha influenza
    |--------------------------------------------------------------------------
    |
    */
    "use_env_for_https" => env("USE_ENV_FOR_HTTPS", false),

];
